pCanary - Sun Nov 18, 2012

Welcome to pCanary's documentation!

***************************************************

Introduction: pCanary basic purpose

========================================

pCanary is a opensource application that is used to lookup information on

crafting and ores in the game Minecraft. It is written in Python and should

be compatible with most operating systems however it has been built for

Linux.

pCanary will create a tk window that will become the interface of selecting

different ores and recipes by the user. The tk window will give the user

an idea on how to construct the crafting on a grid and it will also show

the different ores and their purpose.

pCanary was written by Jeremiah O'Neal aka we6jbo and is released under

the GNU general public license

Sunday, Nov 18 2012 7:42PM PST